#!/bin/sh

git clone https://github.com/FriendsOfCake/crud.git web/api/app/Plugin/Crud
cd web/api/app/Plugin/Crud && git -c advice.detachedHead=false checkout 1429237
git submodule update --init --recursive
rm -rf .*
cd ../../../../..
git clone https://github.com/ZoneMinder/CakePHP-Enum-Behavior.git web/api/app/Plugin/CakePHP-Enum-Behavior
cd web/api/app/Plugin/CakePHP-Enum-Behavior && git -c advice.detachedHead=false checkout ea90c0c
rm -rf .*
cd ../../../../..
git clone https://github.com/ZoneMinder/RtspServer dep/RtspServer
cd dep/RtspServer && git -c advice.detachedHead=false checkout 24e6b71
rm -rf .*
cd ../..
git clone https://github.com/chmike/CxxUrl dep/CxxUrl
cd dep/CxxUrl && git -c advice.detachedHead=false checkout eaf46c0
rm -rf .*
cd ../..

rm -rf .git*
